
Welcome to Makina Django OIDC's documentation!
==============================================


.. toctree::
   :maxdepth: 2
   :caption: 🚀 Getting started

   tutorial

.. toctree::
   :maxdepth: 2
   :caption: 🪄 Advanced usages

   how-to

.. toctree::
   :maxdepth: 4
   :hidden:
   :caption: ⚙️ Settings

   settings.rst


.. toctree::
   :maxdepth: 4
   :hidden:
   :caption: 📚 API Reference

   reference.rst

.. toctree::
   :maxdepth: 2
   :caption: 💡 About this library

   explanation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
